@@ -9,7 +9,7 @@ options(show.signif.stars=FALSE, prompt="R> ", continue="   ",
 
 
 ###################################################
-### code chunk number 2: using-lsmeans.rnw:134-137
+### code chunk number 2: using-lsmeans.rnw:135-138
 ###################################################
 library("lsmeans")
 oranges.lm1 <- lm(sales1 ~ price1 + price2 + day + store, data = oranges)
@@ -17,38 +17,38 @@ anova(oranges.lm1)
 
 
 ###################################################
-### code chunk number 3: using-lsmeans.rnw:140-141
+### code chunk number 3: using-lsmeans.rnw:141-142
 ###################################################
 ( oranges.rg1 <- ref.grid(oranges.lm1) )
 
 
 ###################################################
-### code chunk number 4: using-lsmeans.rnw:144-145
+### code chunk number 4: using-lsmeans.rnw:145-146
 ###################################################
 summary(oranges.rg1)
 
 
 ###################################################
-### code chunk number 5: using-lsmeans.rnw:150-151
+### code chunk number 5: using-lsmeans.rnw:151-152
 ###################################################
 lsmeans(oranges.rg1, "day")   ## or lsmeans(oranges.lm1, "day")
 
 
 ###################################################
-### code chunk number 6: using-lsmeans.rnw:154-155
+### code chunk number 6: using-lsmeans.rnw:155-156
 ###################################################
 with(oranges, tapply(sales1, day, mean))
 
 
 ###################################################
-### code chunk number 7: using-lsmeans.rnw:164-166
+### code chunk number 7: using-lsmeans.rnw:165-167
 ###################################################
 lsmeans(oranges.lm1, "day", at = list(price1 = 50, 
     price2 = c(40,60), day = c("2","3","4")) )
 
 
 ###################################################
-### code chunk number 8: using-lsmeans.rnw:175-178
+### code chunk number 8: using-lsmeans.rnw:176-179
 ###################################################
 org.lsm <- lsmeans(oranges.lm1, "day", by = "price2", 
     at = list(price1 = 50, price2 = c(40,60), day = c("2","3","4")) )
@@ -56,7 +56,7 @@ org.lsm
 
 
 ###################################################
-### code chunk number 9: using-lsmeans.rnw:181-184 (eval = FALSE)
+### code chunk number 9: using-lsmeans.rnw:182-185 (eval = FALSE)
 ###################################################
 ## lsmeans(oranges.lm1, ~ day | price, at = ... )         # Ex 1
 ## lsmeans(oranges.lm1, c("day","price2"), at = ... )     # Ex 2
@@ -64,32 +64,32 @@ org.lsm
 
 
 ###################################################
-### code chunk number 10: using-lsmeans.rnw:194-195
+### code chunk number 10: using-lsmeans.rnw:195-196
 ###################################################
 str(org.lsm)
 
 
 ###################################################
-### code chunk number 11: using-lsmeans.rnw:201-203
+### code chunk number 11: using-lsmeans.rnw:202-204
 ###################################################
 ( org.sum <- summary(org.lsm, infer = c(TRUE,TRUE), 
                     level = .90, adjust = "bon", by = "day") )
 
 
 ###################################################
-### code chunk number 12: using-lsmeans.rnw:208-209
+### code chunk number 12: using-lsmeans.rnw:209-210
 ###################################################
 class(org.sum)
 
 
 ###################################################
-### code chunk number 13: using-lsmeans.rnw:213-214
+### code chunk number 13: using-lsmeans.rnw:214-215
 ###################################################
 transform(org.sum, lsrubles = lsmean * 34.2)
 
 
 ###################################################
-### code chunk number 14: using-lsmeans.rnw:222-224
+### code chunk number 14: using-lsmeans.rnw:223-225
 ###################################################
 org.lsm2 <- update(org.lsm, by.vars = NULL, level = .99)
 org.lsm2
@@ -102,32 +102,32 @@ plot(org.lsm, by = "price2")
 
 
 ###################################################
-### code chunk number 16: using-lsmeans.rnw:246-247
+### code chunk number 16: using-lsmeans.rnw:247-248
 ###################################################
 contrast(org.lsm, method = "eff")
 
 
 ###################################################
-### code chunk number 17: using-lsmeans.rnw:252-254
+### code chunk number 17: using-lsmeans.rnw:253-255
 ###################################################
 days.lsm <- lsmeans(oranges.rg1, "day")
 ( days_contr.lsm <- contrast(days.lsm, "trt.vs.ctrl", ref = c(5,6)) )
 
 
 ###################################################
-### code chunk number 18: using-lsmeans.rnw:259-260 (eval = FALSE)
+### code chunk number 18: using-lsmeans.rnw:260-261 (eval = FALSE)
 ###################################################
 ## confint(contrast(days.lsm, "trt.vs.ctrlk"))
 
 
 ###################################################
-### code chunk number 19: using-lsmeans.rnw:268-269
+### code chunk number 19: using-lsmeans.rnw:269-270
 ###################################################
 pairs(org.lsm)
 
 
 ###################################################
-### code chunk number 20: using-lsmeans.rnw:272-273
+### code chunk number 20: using-lsmeans.rnw:273-274
 ###################################################
 cld(days.lsm, alpha = .10)
 
@@ -139,7 +139,19 @@ plot(days.lsm, comparisons = TRUE, alpha = .10)
 
 
 ###################################################
-### code chunk number 22: using-lsmeans.rnw:294-297
+### code chunk number 22: using-lsmeans.rnw:297-298
+###################################################
+rbind(pairs(org.lsm)[1:3], pairs(org.lsm, by = "day")[1])
+
+
+###################################################
+### code chunk number 23: using-lsmeans.rnw:303-304
+###################################################
+rbind(pairs(lsmeans(org.lsm, "day")), pairs(lsmeans(org.lsm, "price2")))
+
+
+###################################################
+### code chunk number 24: using-lsmeans.rnw:310-313
 ###################################################
 oranges.mlm <- lm(cbind(sales1,sales2) ~ price1 + price2 + day + store, 
                  data = oranges)
@@ -147,33 +159,33 @@ ref.grid(oranges.mlm)
 
 
 ###################################################
-### code chunk number 23: using-lsmeans.rnw:300-302
+### code chunk number 25: using-lsmeans.rnw:316-318
 ###################################################
 org.mlsm <- lsmeans(oranges.mlm, ~ day | variety, mult.name = "variety")
 cld(org.mlsm, sort = FALSE)
 
 
 ###################################################
-### code chunk number 24: using-lsmeans.rnw:310-311
+### code chunk number 26: using-lsmeans.rnw:326-327
 ###################################################
 org.vardiff <- update(pairs(org.mlsm, by = "day"), by = NULL)
 
 
 ###################################################
-### code chunk number 25: using-lsmeans.rnw:314-315
+### code chunk number 27: using-lsmeans.rnw:330-331
 ###################################################
 cld(org.vardiff)
 
 
 ###################################################
-### code chunk number 26: using-lsmeans.rnw:326-328
+### code chunk number 28: using-lsmeans.rnw:342-344
 ###################################################
 # Ensure we see the same results each time
 set.seed(123454321)
 
 
 ###################################################
-### code chunk number 27: using-lsmeans.rnw:330-333
+### code chunk number 29: using-lsmeans.rnw:346-349
 ###################################################
 library("multcomp")
 days.glht <- as.glht(days_contr.lsm)
@@ -181,39 +193,39 @@ summary(days.glht, test = adjusted("Westfall"))
 
 
 ###################################################
-### code chunk number 28: using-lsmeans.rnw:336-338 (eval = FALSE)
+### code chunk number 30: using-lsmeans.rnw:352-354 (eval = FALSE)
 ###################################################
 ## days.glht1 <- glht(oranges.lm1, 
 ##                    lsm("day", contr = "trt.vs.ctrl", ref = c(5,6)))
 
 
 ###################################################
-### code chunk number 29: using-lsmeans.rnw:342-344 (eval = FALSE)
+### code chunk number 31: using-lsmeans.rnw:358-360 (eval = FALSE)
 ###################################################
 ## summary(days_contr.lsm, adjust = "mvt")
 ## summary(days.glht)
 
 
 ###################################################
-### code chunk number 30: using-lsmeans.rnw:350-351 (eval = FALSE)
+### code chunk number 32: using-lsmeans.rnw:366-367 (eval = FALSE)
 ###################################################
 ## summary(as.glht(pairs(org.lsm)))
 
 
 ###################################################
-### code chunk number 31: using-lsmeans.rnw:354-355 (eval = FALSE)
+### code chunk number 33: using-lsmeans.rnw:370-371 (eval = FALSE)
 ###################################################
 ## summary(as.glht(pairs(org.lsm), by = NULL))
 
 
 ###################################################
-### code chunk number 32: using-lsmeans.rnw:358-359 (eval = FALSE)
+### code chunk number 34: using-lsmeans.rnw:374-375 (eval = FALSE)
 ###################################################
 ## summary(as.glht(pairs(org.lsm, by = NULL)))
 
 
 ###################################################
-### code chunk number 33: using-lsmeans.rnw:371-376
+### code chunk number 35: using-lsmeans.rnw:387-392
 ###################################################
 data("Oats", package = "nlme")
 library("lme4")
@@ -223,88 +235,88 @@ anova(Oats.lmer)
 
 
 ###################################################
-### code chunk number 34: oatcontr (eval = FALSE)
+### code chunk number 36: oatcontr (eval = FALSE)
 ###################################################
 ## contrast(lsmeans(Oats.lmer, "nitro"), "poly")
 
 
 ###################################################
-### code chunk number 35: using-lsmeans.rnw:383-384
+### code chunk number 37: using-lsmeans.rnw:399-400
 ###################################################
 cat("NOTE: Results may be misleading due to involvement in interactions")
 
 
 ###################################################
-### code chunk number 36: using-lsmeans.rnw:386-387
+### code chunk number 38: using-lsmeans.rnw:402-403
 ###################################################
 contrast(lsmeans(Oats.lmer, "nitro"), "poly")
 
 
 ###################################################
-### code chunk number 37: using-lsmeans.rnw:390-392
+### code chunk number 39: using-lsmeans.rnw:406-408
 ###################################################
 Oats.lmer2 <- lmer(log(yield) ~ Variety + poly(nitro,2) 
                                 + (1|Block/Variety),  data = Oats)
 
 
 ###################################################
-### code chunk number 38: using-lsmeans.rnw:395-397
+### code chunk number 40: using-lsmeans.rnw:411-413
 ###################################################
 Oats.lsm2 <- lsmeans(Oats.lmer2, ~ nitro | Variety, cov.reduce = FALSE)
 Oats.lsm2
 
 
 ###################################################
-### code chunk number 39: oatslmer
+### code chunk number 41: oatslmer
 ###################################################
 lsmip(Oats.lmer, Variety ~ nitro, ylab = "Observed log(yield)")
 
 
 ###################################################
-### code chunk number 40: oatslmer2
+### code chunk number 42: oatslmer2
 ###################################################
 lsmip(Oats.lsm2, Variety ~ nitro, ylab = "Predicted log(yield)")
 
 
 ###################################################
-### code chunk number 41: using-lsmeans.rnw:438-439
+### code chunk number 43: using-lsmeans.rnw:454-455
 ###################################################
 str(Oats.lsm2)
 
 
 ###################################################
-### code chunk number 42: using-lsmeans.rnw:442-443
+### code chunk number 44: using-lsmeans.rnw:458-459
 ###################################################
 summary(Oats.lsm2, type = "response")
 
 
 ###################################################
-### code chunk number 43: using-lsmeans.rnw:459-461
+### code chunk number 45: using-lsmeans.rnw:475-477
 ###################################################
 Oats.Vlsm = lsmeans(Oats.lmer2, "Variety")
 test(Oats.Vlsm, null = log(100), type = "response")
 
 
 ###################################################
-### code chunk number 44: using-lsmeans.rnw:473-474
+### code chunk number 46: using-lsmeans.rnw:489-490
 ###################################################
 test(Oats.Vlsm, null = log(100), delta = 0.20, type = "r")
 
 
 ###################################################
-### code chunk number 45: using-lsmeans.rnw:480-481
+### code chunk number 47: using-lsmeans.rnw:496-497
 ###################################################
 test(contrast(Oats.Vlsm, "trt.vs.ctrlk"), side = ">")
 
 
 ###################################################
-### code chunk number 46: using-lsmeans.rnw:484-485
+### code chunk number 48: using-lsmeans.rnw:500-501
 ###################################################
 test(contrast(Oats.Vlsm, "trt.vs.ctrlk"), side = "nonsup", delta = .25)
 
 
 ###################################################
-### code chunk number 47: chick-plot
+### code chunk number 49: chick-plot
 ###################################################
 require("lattice")
 xyplot(weight~Time | Diet, groups = ~ Chick, data = ChickWeight, 
@@ -312,26 +324,26 @@ xyplot(weight~Time | Diet, groups = ~ Chick, data = ChickWeight,
 
 
 ###################################################
-### code chunk number 48: using-lsmeans.rnw:506-508
+### code chunk number 50: using-lsmeans.rnw:522-524
 ###################################################
 Chick.lmer <- lmer(weight ~ Diet * Time + (0 + Time | Chick), 
     data = ChickWeight)
 
 
 ###################################################
-### code chunk number 49: using-lsmeans.rnw:511-512
+### code chunk number 51: using-lsmeans.rnw:527-528
 ###################################################
 ( Chick.lst <- lstrends (Chick.lmer, ~ Diet, var = "Time") )
 
 
 ###################################################
-### code chunk number 50: using-lsmeans.rnw:515-516
+### code chunk number 52: using-lsmeans.rnw:531-532
 ###################################################
 cld (Chick.lst)
 
 
 ###################################################
-### code chunk number 51: using-lsmeans.rnw:527-530
+### code chunk number 53: using-lsmeans.rnw:543-546
 ###################################################
 lsm.options(ref.grid = list(level = .90),
             lsmeans = list(),
@@ -339,19 +351,19 @@ lsm.options(ref.grid = list(level = .90),
 
 
 ###################################################
-### code chunk number 52: using-lsmeans.rnw:543-544
+### code chunk number 54: using-lsmeans.rnw:559-560
 ###################################################
 lsmeans(Oats.lmer2, pairwise ~ Variety)
 
 
 ###################################################
-### code chunk number 53: using-lsmeans.rnw:548-549
+### code chunk number 55: using-lsmeans.rnw:564-565
 ###################################################
 lsm.options(ref.grid = NULL, contrast = NULL)
 
 
 ###################################################
-### code chunk number 54: using-lsmeans.rnw:559-562
+### code chunk number 56: using-lsmeans.rnw:575-578
 ###################################################
 nutr.lm <- lm(gain ~ (age + group + race)^2, data = nutrition)
 library("car")
@@ -359,21 +371,21 @@ Anova(nutr.lm)
 
 
 ###################################################
-### code chunk number 55: nutr-intplot
+### code chunk number 57: nutr-intplot
 ###################################################
 lsmip(nutr.lm, race ~ age | group)
 lsmeans(nutr.lm, ~ group*race)
 
 
 ###################################################
-### code chunk number 56: using-lsmeans.rnw:579-581
+### code chunk number 58: using-lsmeans.rnw:595-597
 ###################################################
 nutr.lsm <- lsmeans(nutr.lm, ~ group * race, weights = "proportional",
     at = list(age = c("2","3"), race = c("Black","White")))
 
 
 ###################################################
-### code chunk number 57: using-lsmeans.rnw:584-587
+### code chunk number 59: using-lsmeans.rnw:600-603
 ###################################################
 nutr.lsm    
 summary(pairs(nutr.lsm, by = "race"), by = NULL)
@@ -381,7 +393,7 @@ summary(pairs(nutr.lsm, by = "group"), by = NULL)
 
 
 ###################################################
-### code chunk number 58: using-lsmeans.rnw:600-604
+### code chunk number 60: using-lsmeans.rnw:616-620
 ###################################################
 lsmeans(nutr.lm, "race", weights = "equal")
 lsmeans(nutr.lm, "race", weights = "prop")
@@ -390,20 +402,20 @@ lsmeans(nutr.lm, "race", weights = "cells")
 
 
 ###################################################
-### code chunk number 59: using-lsmeans.rnw:613-615
+### code chunk number 61: using-lsmeans.rnw:629-631
 ###################################################
 temp = lsmeans(nutr.lm, c("group","race"), weights = "prop")
 lsmeans(temp, "race", weights = "prop")
 
 
 ###################################################
-### code chunk number 60: using-lsmeans.rnw:620-621
+### code chunk number 62: using-lsmeans.rnw:636-637
 ###################################################
 with(nutrition, tapply(gain, race, mean))
 
 
 ###################################################
-### code chunk number 61: using-lsmeans.rnw:628-632
+### code chunk number 63: using-lsmeans.rnw:644-648
 ###################################################
 library("mediation")
 levels(framing$educ) = c("NA","Ref","< HS", "HS", "> HS","Coll +")
@@ -412,34 +424,34 @@ framing.glm = glm(cong_mesg ~ age + income + educ + emo + gender * factor(treat)
 
 
 ###################################################
-### code chunk number 62: framinga
+### code chunk number 64: framinga
 ###################################################
 lsmip(framing.glm, treat ~ educ | gender, type = "response")
 
 
 ###################################################
-### code chunk number 63: framingb
+### code chunk number 65: framingb
 ###################################################
 lsmip(framing.glm, treat ~ educ | gender, type = "response",
       cov.reduce = emo ~ treat*gender + age + educ + income)
 
 
 ###################################################
-### code chunk number 64: using-lsmeans.rnw:659-661
+### code chunk number 66: using-lsmeans.rnw:675-677
 ###################################################
 ref.grid(framing.glm, 
     cov.reduce = emo ~ treat*gender + age + educ + income)@grid
 
 
 ###################################################
-### code chunk number 65: using-lsmeans.rnw:692-694 (eval = FALSE)
+### code chunk number 67: using-lsmeans.rnw:708-710 (eval = FALSE)
 ###################################################
 ## rg <- ref.grid(my.model, at = list(x1 = c(5,10,15)),
 ##                cov.reduce = list(x2 ~ x1,  x3 ~ x1 + x2))
 
 
 ###################################################
-### code chunk number 66: housing-plot
+### code chunk number 68: housing-plot
 ###################################################
 library("ordinal")
 data(housing, package = "MASS")
@@ -449,39 +461,39 @@ lsmip(housing.clm, Cont ~ Infl | Type, layout = c(4,1))
 
 
 ###################################################
-### code chunk number 67: using-lsmeans.rnw:739-740
+### code chunk number 69: using-lsmeans.rnw:755-756
 ###################################################
 test(pairs(lsmeans(housing.clm, ~ Infl | Type)), joint = TRUE)
 
 
 ###################################################
-### code chunk number 68: using-lsmeans.rnw:743-744
+### code chunk number 70: using-lsmeans.rnw:759-760
 ###################################################
 test(pairs(lsmeans(housing.clm, ~ Cont | Type)), joint = TRUE)
 
 
 ###################################################
-### code chunk number 69: using-lsmeans.rnw:749-750
+### code chunk number 71: using-lsmeans.rnw:765-766
 ###################################################
 ref.grid(housing.clm, mode = "cum.prob")
 
 
 ###################################################
-### code chunk number 70: using-lsmeans.rnw:753-755
+### code chunk number 72: using-lsmeans.rnw:769-771
 ###################################################
 lsmeans(housing.clm, ~ Infl, at = list(cut = "Medium|High"), 
         mode = "cum.prob")
 
 
 ###################################################
-### code chunk number 71: using-lsmeans.rnw:758-760
+### code chunk number 73: using-lsmeans.rnw:774-776
 ###################################################
 summary(lsmeans(housing.clm, ~ Infl, at = list(cut = "Medium|High"), 
                 mode = "linear.predictor"), type = "response")
 
 
 ###################################################
-### code chunk number 72: using-lsmeans.rnw:768-776
+### code chunk number 74: using-lsmeans.rnw:784-792
 ###################################################
 require("nlme")
 options(contrasts = c("contr.treatment", "contr.poly"))
@@ -494,14 +506,14 @@ Chick.nlme
 
 
 ###################################################
-### code chunk number 73: using-lsmeans.rnw:779-781
+### code chunk number 75: using-lsmeans.rnw:795-797
 ###################################################
 cld(lsmeans(Chick.nlme, ~ Diet, param = "asym"))    
 cld(lsmeans(Chick.nlme, ~ Diet, param = "xmid"))    
 
 
 ###################################################
-### code chunk number 74: using-lsmeans.rnw:793-798
+### code chunk number 76: using-lsmeans.rnw:809-814
 ###################################################
 library("MCMCpack")
 counts <- c(18, 17, 15,   20, 10, 20,   25, 13, 12)
@@ -511,13 +523,13 @@ posterior <- MCMCpoisson(counts ~ outcome + treatment, mcmc = 1000)
 
 
 ###################################################
-### code chunk number 75: using-lsmeans.rnw:801-802
+### code chunk number 77: using-lsmeans.rnw:817-818
 ###################################################
 ( post.lsm <- lsmeans(posterior, "treatment") )
 
 
 ###################################################
-### code chunk number 76: using-lsmeans.rnw:805-807
+### code chunk number 78: using-lsmeans.rnw:821-823
 ###################################################
 library("coda")
 summary(as.mcmc(post.lsm))
